Documentation
¶
Overview ¶
Package ekstester defines interface EKS cluster tester and deployer.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Deployer ¶
type Deployer interface {
Up() error
IsUp() error
TestSetup() error
Down() error
GetClusterCreated(gcpProject string) (time.Time, error)
DumpClusterLogs(artifactDir, _ string) error
// GetWorkerNodeLogs downloads logs from worker node machines.
GetWorkerNodeLogs() error
// Stop stops ongoing operations.
// This is useful for local development.
// For example, one may run "Up" but have to cancel onging "Up"
// operation. Then, it can just send syscall.SIGINT to trigger "Stop".
Stop()
// LoadConfig reloads configuration from disk to read the latest
// cluster configuration and its states.
// It's either reloaded from disk or returned from embedded EKS deployer.
LoadConfig() (eksconfig.Config, error)
// KubectlCommand returns "kubectl" command object for API reachability tests.
KubectlCommand() (*osexec.Cmd, error)
// KubernetesClientSet returns Kubernetes Go client.
KubernetesClientSet() *kubernetes.Clientset
}
Deployer defines EKS deployer. Satisfies "k8s.io/test-infra/kubetest/main.go" 'deployer' interfaces. Reference https://github.com/kubernetes/test-infra/blob/master/kubetest/main.go.
Click to show internal directories.
Click to hide internal directories.